# -*- coding: Latin-1 -*-
#
# SMM Share and Money Management
# Copyright (c) 2007-2009 Carsten Grohmann
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; version 2 of the
# License.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
# 02110-1301, USA.

## \file gui/images.py
#
# \short Image store
#
# \author Carsten Grohmann <mail (at) carstengrohmann (dot) de>
#
# \par License:
# GPL version 2.0
#
# \version $Id: images.py,v 1.6 2009-04-06 13:36:26 carsten Exp $
#
# \par Revision History:
# \code
# $Log: images.py,v $
# Revision 1.6  2009-04-06 13:36:26  carsten
# - typo in license statement
#
# Revision 1.5  2009-04-06 07:56:19  carsten
# - update copyright string
# - unify python coding line
#
# Revision 1.4  2008-04-27 19:50:44  carsten
# - replace "stock" by "share" - I like British English :-)
#
# Revision 1.3  2008-01-08 19:04:04  carsten
# - second rework to simplify used code
# - add blankImage
#
# Revision 1.2  2008-01-07 19:16:49  carsten
# - Replace all images by own XPM images
# - add new images
# \endcode

import wx
import StringIO


## \brief Converts XPM data from a string into a wx.Bitmap object
#
#  \param data String with XPM data
#
#  \return A \c wx.Bitmap
def XPM2Bitmap(data):
    lines = [s.strip() for s in data.splitlines()]
    stream = StringIO.StringIO(''.join(lines))
    img = wx.ImageFromStream(stream)
    return wx.BitmapFromImage(img)


#######################################################################
#
# Up arrow image
#
#######################################################################

smallUpArrowData = """
/* XPM */
static char *arrow_up_black_16x16[]={
"16 16 2 1",
". c None",
"# c #000000",
"................",
"................",
"................",
"................",
"................",
".......##.......",
"......####......",
".....######.....",
"....########....",
"...##########...",
"..############..",
"................",
"................",
"................",
"................",
"................"};
"""

def getSmallUpArrowBitmap():
    return XPM2Bitmap(smallUpArrowData)


#######################################################################
#
# Down arrow image
#
#######################################################################

smallDownArrowData = """
/* XPM */
static char *arrow_down_black_16x16[]={
"16 16 2 1",
". c None",
"# c #000000",
"................",
"................",
"................",
"................",
"................",
"..############..",
"...##########...",
"....########....",
".....######.....",
"......####......",
".......##.......",
"................",
"................",
"................",
"................",
"................"};
"""

def getSmallDnArrowBitmap():
    return XPM2Bitmap(smallDownArrowData)

#######################################################################
#
# Green arrow image
#
#######################################################################

smallGreenArrowData = """
/* XPM */
static char *arrow_green_16x16[]={
"16 16 2 1",
". c None",
"# c #00ff00",
"................",
"........#######.",
"........#######.",
"...........####.",
"..........#####.",
".........###.##.",
"........###..##.",
".......###...##.",
"......###.......",
".....###........",
"....###.........",
"...###..........",
"...##...........",
"................",
"................",
"................"};
"""

def getSmallGreenArrowBitmap():
    return XPM2Bitmap(smallGreenArrowData)


#######################################################################
#
# Red arrow image
#
#######################################################################

smallRedArrowData = """
/* XPM */
static char *arrow_red_16x16[]={
"16 16 2 1",
". c None",
"# c #ff0000",
"................",
"................",
"................",
"...##...........",
"...###..........",
"....###.........",
".....###........",
"......###.......",
".......###...##.",
"........###..##.",
".........###.##.",
"..........#####.",
"...........####.",
"........#######.",
"........#######.",
"................"};
"""

def getSmallRedArrowBitmap():
    return XPM2Bitmap(smallRedArrowData)


#######################################################################
#
# Yellow arrow image
#
#######################################################################

smallYellowArrowData = """
/* XPM */
static char *arrow_yellow_16x16[]={
"16 16 2 1",
". c None",
"# c #ffff00",
"................",
"................",
"................",
"..........#.....",
"..........##....",
"..........###...",
"..........####..",
"..#############.",
"..#############.",
"..........####..",
"..........###...",
"..........##....",
"..........#.....",
"................",
"................",
"................"};
"""

def getSmallYellowArrowBitmap():
    return XPM2Bitmap(smallYellowArrowData)


#######################################################################
#
# Blank image
#
#######################################################################

blankImageData = """
/* XPM */
static char *blank_16x16[]={
"16 16 1 1",
". c None",
"................",
"................",
"................",
"................",
"................",
"................",
"................",
"................",
"................",
"................",
"................",
"................",
"................",
"................",
"................",
"................"};
"""

def getBlankImageBitmap():
    return XPM2Bitmap(blankImageData)
