#!/usr/bin/env  python
# -*- coding: Latin-1 -*-
#
# SMM Share and Money Management
# Copyright (c) 2007-2010 Carsten Grohmann
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; version 2 of the
# License.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
# 02110-1301, USA.

## \file tests/test_misc.py
#
# \brief Test miscellaneous functions
#
# \author Carsten Grohmann <mail (at) carstengrohmann (dot) de>
#
# \par License:
# GPL version 2.0


# import general python modules
import decimal
import unittest

# import project modules
import smm

## \brief Test basic functionality with all objects from smm.objects
#
#  Tests creation, searching, adding and removing of all object classes
class TestMisc(unittest.TestCase):

    ## Initialise SMM
    def setUp(self):
        smm.init()


    ## Tests creating, searching and destroying smm.objects.Exchange objects
    def test_toDecimal(self):

        fetch = smm.quote.base.FetchPluginBase()

        # check for Decimal
        self.failUnlessEqual(
            fetch.toDecimal(decimal.Decimal("2")),
            decimal.Decimal("2"),
            )
        # check for non-Unicode
        self.failUnlessRaises(
            TypeError,
            fetch.toDecimal,
            2
            )
        # check for None
        self.failUnlessRaises(
            TypeError,
            fetch.toDecimal,
            None,
            )
        # check for Unicode scrap
        self.failUnlessRaises(
            ValueError,
            fetch.toDecimal,
            u':'
            )

        # check general functionality
        self.failUnlessEqual(
            fetch.toDecimal(u'2'),
            decimal.Decimal("2"),
            )
        # work because thousands separator isn't defined
        self.failUnlessEqual(
            fetch.toDecimal(u'2.0'),
            decimal.Decimal("2"),
            )
        # work because decimal separator is set to "," per default
        self.failUnlessEqual(
            fetch.toDecimal(u'2,0'),
            decimal.Decimal("2"),
            )
        # check thousands separator
        self.failUnlessEqual(
            fetch.toDecimal(u"2.000,01", tsep=u"."),
            decimal.Decimal("2000.01"),
            )

        # check various spaces
        self.failUnlessEqual(
            fetch.toDecimal(u' 2 '),
            decimal.Decimal("2"),
            )
        self.failUnlessEqual(
            fetch.toDecimal(u'2 '),
            decimal.Decimal("2"),
            )
        self.failUnlessEqual(
            fetch.toDecimal(u' 2'),
            decimal.Decimal("2"),
            )

        # check percent handling
        self.failUnlessEqual(
            fetch.toDecimal(u'2%'),
            decimal.Decimal("0.02"),
            )
        self.failUnlessEqual(
            fetch.toDecimal(u'2 %'),
            decimal.Decimal("0.02"),
            )
        self.failUnlessEqual(
            fetch.toDecimal(u"2.000,01 %", tsep=u"."),
            decimal.Decimal("20.0001"),
            )
